Crate buttplug_websocket_connector_no_tokio_net

Crate buttplug_websocket_connector_no_tokio_net 

Structs

ButtplugWebsocketClientTransport
Websocket connector for ButtplugClients, using tokio_tungstenite
ButtplugWebsocketServerTransport
Websocket connector for ButtplugClients, using tokio_tungstenite
ButtplugWebsocketServerTransportBuilder

Functions

new_json_ws_client_connector
Convenience method for creating a new Buttplug Client Websocket connector that uses the JSON serializer. This is pretty much the only connector used for IPC right now, so this makes it easy to create one without having to fill in the generic types.