Structs
- Buttplug
Websocket Client Transport - Websocket connector for ButtplugClients, using tokio_tungstenite
- Buttplug
Websocket Server Transport - Websocket connector for ButtplugClients, using tokio_tungstenite
- Buttplug
Websocket Server Transport Builder
Functions
- new_
json_ ws_ client_ connector - Convenience method for creating a new Buttplug Client Websocket connector that uses the JSON serializer. This is pretty much the only connector used for IPC right now, so this makes it easy to create one without having to fill in the generic types.